powered by
Does not change the data set, but returns a class suitable for plotting raw data with plot.breathtestfit. See read_any_breathtest for an example.
plot.breathtestfit
read_any_breathtest
null_fit(data, ...)
A list of classes breathtestnullfit, breathtestfit
breathtestnullfit, breathtestfit
with element data which contains the unmodified data.
data
Data frame or tibble as created by cleanup_data, with mandatory columns patient_id, group, minute and pdr.
cleanup_data
patient_id, group, minute
pdr
Not used