Learn R Programming

breathtestcore (version 0.8.7)

usz_13c_a: Exotic 13C breath test data

Description

13C time series PDR data from three different groups in a randomized (= not-crossover) design. This are unpublished data from Gastroenterology and Hepatology, University Hospital Zurich.

Data are formatted as described in usz_13c. These time series present a challenge for algorithms.

Usage

data(usz_13c_a)

Arguments

Examples

Run this code
# \donttest{
library(dplyr)
library(ggplot2)
data(usz_13c_a)
d = usz_13c_a %>% 
  cleanup_data() %>% # recommended to test for validity
  nlme_fit()
plot(d)
# }

Run the code above in your browser using DataLab