- patient_id
required, string or number for unique identification
- name
optional
- first_name
optional
- initials
optional, 2 characters, 1 number
- dob
optional date of birth (not to be confused with "delta over baseline")
- birth_year
optional
- gender
optional m or f
- study
optional name of study; can be used in population fit
- pat_study_id
optional; patient number within study_ does not need to be globally unique
- file_name
required; file where data were read from, or other unique string_
when data are read again, this string is tested and record is skipped when
same filename is already in database, therefore uniqueness is important_ when some
record does not turn up in database after repeated reading, check if a record with
the same file name is already there, and rename the file to avoid collisions_
- device
breath_id or iris; default "generic"
- substrate
should contain string "ace" or "oct" or "okt", case insensitive_ will
be replaced by "acetate" or "octanoate". If empty, "ocatanoate" is assumed.
- record_date
required record date_
- start_time
optional
- end_time
optional
- test_no
required integer; unique test number converted to integer if factor
- dose
optional, default 100 mg
- height
optional, in cm; when pdr must be calculated, default values are
used; see dob_to_pdr
- weight
optional, in kg
- t50
optional, only present if device computes this value
- gec
optional, only present if device computes this value
- tlag
optional, only present if device computes this value
- data
data frame with at least 5 rows and columns minute or
time and one or both of dob or pdr.
If pdr is missing, and height, weight
and substrate are given, computes pdr via function dob_to_pdr.
When height and weight are missing, defaults 180 cm and 75 kg are used instead.