Learn R Programming

breathtestcore (version 0.8.7)

btcore_file: Path to example breath test data file

Description

Path to example breath test data file

Usage

btcore_file(filename = NULL, full.names = FALSE)

Value

full filename to example file to use in read_xxx

Arguments

filename

example file in extdata directory without path. Case sensitive on Unix. When filename is missing, returns the names of the available sample files.

full.names

When filename is NULL, return full path names

Examples

Run this code
  head(btcore_file())
  filename = btcore_file("IrisMulti.TXT")
  data = read_iris(filename)

Run the code above in your browser using DataLab