powered by
Path to example breath test data file
btcore_file(filename = NULL, full.names = FALSE)
full filename to example file to use in read_xxx
example file in extdata directory without path. Case sensitive on Unix. When filename is missing, returns the names of the available sample files.
extdata
When filename is NULL, return full path names
filename
head(btcore_file()) filename = btcore_file("IrisMulti.TXT") data = read_iris(filename)
Run the code above in your browser using DataLab